package ink.wgink.service.core.controller.api.manage;

import ink.wgink.common.base.DefaultBaseController;
import ink.wgink.interfaces.consts.ISystemConstant;
import ink.wgink.pojo.ListPage;
import ink.wgink.pojo.dtos.department.DepartmentDTO;
import ink.wgink.pojo.dtos.user.UserDTO;
import ink.wgink.pojo.result.ErrorResult;
import ink.wgink.pojo.result.SuccessResultList;
import ink.wgink.service.core.service.manage.ICoreManageService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * @ClassName: CoreManageController
 * @Description: 核心管理
 * @Author: wanggeng
 * @Date: 2022/8/10 16:27
 * @Version: 1.0
 */
@Api(tags = ISystemConstant.API_TAGS_SYSTEM_PREFIX + "核心业务")
@RestController
@RequestMapping(ISystemConstant.API_PREFIX + "/core/manage")
public class CoreManageController extends DefaultBaseController {

    @Autowired
    private ICoreManageService coreManageService;

    @ApiOperation(value = "组织部门导航列表", notes = "通过组织部门ID获取与查询有关的所有组织部门列表接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "departmentId", value = "组织部门上级ID", paramType = "path")
    })
    @ApiResponses({@ApiResponse(code = 400, message = "请求失败", response = ErrorResult.class)})
    @GetMapping("list-department-nav-path/department-id/{departmentId}")
    public List<DepartmentDTO> listDepartmentNavPathByDepartmentId(@PathVariable("departmentId") String departmentId) {
        return coreManageService.listDepartmentNavPathByDepartmentId(departmentId);
    }

    @ApiOperation(value = "组织部门用户列表", notes = "组织部门用户列表接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "departmentId", value = "部门ID", paramType = "path"),
            @ApiImplicitParam(name = "roleId", value = "部门ID", paramType = "query"),
            @ApiImplicitParam(name = "positionId", value = "部门ID", paramType = "query"),
            @ApiImplicitParam(name = "groupId", value = "部门ID", paramType = "query"),
            @ApiImplicitParam(name = "keywords", value = "关键字", paramType = "query"),
            @ApiImplicitParam(name = "userType", value = "用户类型", paramType = "query"),
            @ApiImplicitParam(name = "userStatus", value = "用户状态", paramType = "query"),
            @ApiImplicitParam(name = "page", value = "当前页码", paramType = "query", dataType = "int", defaultValue = "1"),
            @ApiImplicitParam(name = "rows", value = "显示数量", paramType = "query", dataType = "int", defaultValue = "20"),
    })
    @ApiResponses({@ApiResponse(code = 400, message = "请求失败", response = ErrorResult.class)})
    @GetMapping("listpage-user/department-id/{departmentId}")
    public SuccessResultList<List<UserDTO>> listPageUserByDepartmentId(@PathVariable("departmentId") String departmentId, ListPage page) {
        Map<String, Object> requestParams = requestParams();
        page.setParams(requestParams);
        return coreManageService.listPageUserByDepartmentId(departmentId, page);
    }

}
