package ink.wgink.service.core.service.manage.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import ink.wgink.common.base.DefaultBaseService;
import ink.wgink.exceptions.SearchException;
import ink.wgink.interfaces.consts.ISystemConstant;
import ink.wgink.pojo.ListPage;
import ink.wgink.pojo.dtos.department.DepartmentDTO;
import ink.wgink.pojo.dtos.user.UserDTO;
import ink.wgink.pojo.pos.DepartmentPO;
import ink.wgink.pojo.result.SuccessResultList;
import ink.wgink.service.core.dao.manage.ICoreManageDao;
import ink.wgink.service.core.service.manage.ICoreManageService;
import ink.wgink.service.department.service.IDepartmentService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @ClassName: CoreManageServiceImpl
 * @Description: 核心管理业务
 * @Author: wanggeng
 * @Date: 2022/8/10 16:28
 * @Version: 1.0
 */
@Service
public class CoreManageServiceImpl extends DefaultBaseService implements ICoreManageService {

    @Autowired
    private IDepartmentService departmentService;
    @Autowired
    private ICoreManageDao coreManageDao;

    @Override
    public List<DepartmentDTO> listDepartmentNavPathByDepartmentId(String departmentId) {
        DepartmentPO departmentPO = departmentService.getPO(departmentId);
        if (departmentPO == null) {
            throw new SearchException("部门不存在");
        }
        List<DepartmentDTO> navList = new ArrayList<>();
        setDepartmentNav(navList, departmentPO);
        return navList;
    }

    @Override
    public List<UserDTO> listUser(Map<String, Object> params) {
        params = params == null ? getHashMap(0) : params;
        return coreManageDao.listUser(params);
    }

    @Override
    public SuccessResultList<List<UserDTO>> listPageUserByDepartmentId(String departmentId, ListPage page) {
        page.getParams().put("departmentId", departmentId);
        PageHelper.startPage(page.getPage(), page.getRows());
        List<UserDTO> userDTOs = listUser(page.getParams());
        PageInfo<UserDTO> pageInfo = new PageInfo<>(userDTOs);
        return new SuccessResultList<>(userDTOs, pageInfo.getPageNum(), pageInfo.getTotal());
    }

    /**
     * 设置部门导航
     *
     * @param navList
     * @param departmentPO
     */
    private void setDepartmentNav(List<DepartmentDTO> navList, DepartmentPO departmentPO) {
        DepartmentDTO departmentDTO = new DepartmentDTO();
        BeanUtils.copyProperties(departmentPO, departmentDTO);
        navList.add(0, departmentDTO);
        if (StringUtils.equals(ISystemConstant.TREE_ROOT_ID, departmentPO.getDepartmentParentId())) {
            return;
        }
        DepartmentPO departmentParentPO = departmentService.getPO(departmentPO.getDepartmentParentId());
        setDepartmentNav(navList, departmentParentPO);
    }
}
